# This function is for the initial conversion of empirical COS NUV PSFs to a format the pandeia.engine can use.
# It will not be used on a regular basis.

import numpy as np
import stsynphot as st
from astropy.io import fits
import astropy.units as u
import sys

from photutils.centroids import centroid_2dg

randomseed = 2021

instrument = sys.argv[1]
aperture = sys.argv[2]
filename = sys.argv[3]
filterband = sys.argv[4]

with fits.open(filename) as infile:
    events = infile[1].data

data = np.zeros((1024,1024))

time = events.field('TIME')
xcorr = events.field('XCORR')
ycorr = events.field('YCORR')

np.random.seed(randomseed)
for idx in range(len(time)):
    # cut out the flash
    if (time[idx] > 20.0) and ((time[idx] < 435.0) or (time[idx] > 455.0)) and ((time[idx] < 870.0) or (time[idx] > 895.0)):
        # accumulate photons
        randx = np.random.random_sample(1)-0.5
        randy = np.random.random_sample(1)-0.5
        data[int(ycorr[idx] + randy),int(xcorr[idx] + randx)] += 1

centerx, centery = centroid_2dg(data)
offsetx = (centerx % 1) - 0.2 # Values from Sean Lockwood
offsety = (centery % 1) - 0.1 # Values from Sean Lockwood
print(centerx,centery)

# second pass, with offsets to center the PSF
data = np.zeros((1024,1024))
np.random.seed(randomseed)
for idx in range(len(time)):
    # cut out the flash
    if (time[idx] > 20.0) and ((time[idx] < 435.0) or (time[idx] > 455.0)) and ((time[idx] < 870.0) or (time[idx] > 895.0)):
        # accumulate photons
        randx = np.random.random_sample(1)-0.5
        randy = np.random.random_sample(1)-0.5
        data[int(ycorr[idx]-offsety + randy),int(xcorr[idx]-offsetx + randx)] += 1

data = data/np.sum(data)
print(np.sum(data))

centerx, centery = centroid_2dg(data)
print(centerx,centery)

centerx = int(np.round(centerx))
centery = int(np.round(centery))
data = data[centery-31:centery+32, centerx-31:centerx+32]
print(np.sum(data))

tab = fits.open(filename)
bp = st.spectrum.band(filterband)
#print(bp.efficiency())
#data = data/np.sum(data)

#data = data * bp.tpeak().value

#tab[0].data = tab[0].data/bp.tpeak().value
waves = [0.16*u.micron, bp.avgwave(), 0.33*u.micron]
for wave in waves:
    hdu = fits.PrimaryHDU(data)
    hdulist = fits.HDUList([hdu])
    hdulist[0].header['WAVE0'] = wave.to_value(u.m)
    hdulist[0].header['INSTRUME'] = instrument
    hdulist[0].header['APERTURE'] = aperture
    hdulist[0].header['NWAVES'] = 1 # not actually true, but has to be for this experiment
    hdulist[0].header['PIXSCLX'] = 0.075
    hdulist[0].header['PIXSCLY'] = 0.075
    hdulist[0].header['DIFFLMT'] = (1.22 * wave.to_value(u.m) / 2.4) * 180/np.pi*3600
    hdulist[0].header['PUP_THRU'] = np.sum(data)
    hdulist[0].header['DET_SAMP'] = 1 # real data, no oversampling
    hdulist[0].header['COMMENT'] = "From observation laa701a8q (CALCOS, Alessandra Aloisi 2011)"
    hdulist[0].header['COMMENT'] = "with filter throughput removed and event locations randomized"
    hdulist[0].header['COMMENT'] = "by numpy.random.random_sample()-0.5 seeded with 2021."
    hdulist[0].header['COMMENT'] = "Pixels have been offset by an additional (0.1,0.2) from their"
    hdulist[0].header['COMMENT'] = "newly-computed center, as determined by Sean Lockwood."
    hdulist[0].header['COMMENT'] = f"Extraction of 63x63 pixels centered on ({centerx},{centery})"
    hdulist[0].header['COMMENT'] = "(as computed by photutils with 2D gaussian.)"
    hdulist[0].header['COMMENT'] = "Generated 2021.1118 by A. Riedel with COSNUVconvert.py"
    hdulist.writeto('{}_{}_{:0.4f}.fits'.format(instrument, aperture, wave.to_value(u.um)))
