# This function is for the initial conversion of empirical WFC3 PSFs to a format the pandeia.engine can use.
# It will not be used on a regular basis.

import numpy as np
import stsynphot as st
import synphot as syn
from astropy.io import fits
import astropy.units as u
import sys

instrument = sys.argv[1]
aperture = sys.argv[2]
filename = sys.argv[3]
filterband = sys.argv[4]

tab = fits.open(filename)
bp = st.spectrum.band(filterband)
print(bp.efficiency())

print(tab[0].data.shape)
#data = tab[0].data[17] #PSF 18 is the one to use, per Jay Anderson
data = tab[0].data[4] #PSF 18 is the one to use, per Jay Anderson
data = data[2::4,2::4] # the flux is sampled, not distributed, over all the pixels
#data = data/bp.tpeak().value
data = np.clip(data,0, None) # zero out edges of the PSF

hdu = fits.PrimaryHDU(data)
hdulist = fits.HDUList([hdu])
#tab[0].data = tab[0].data/bp.tpeak().value
avgwave = bp.avgwave()
hdulist[0].header['WAVE0'] = avgwave.to_value(u.m)
hdulist[0].header['INSTRUME'] = instrument
hdulist[0].header['APERTURE'] = aperture
hdulist[0].header['NWAVES'] = 1 # not actually true, but has to be for this experiment
hdulist[0].header['PIXSCLX'] = 0.1211 # though it's not really square
hdulist[0].header['PIXSCLY'] = 0.1355 # though it's not really square
#hdulist[0].header['PIXSCLX'] = 0.0397 # though it's not really square
#hdulist[0].header['PIXSCLY'] = 0.0395 # though it's not really square
hdulist[0].header['DIFFLMT'] = (1.22 * avgwave.to_value(u.m) / 2.4) * 180/np.pi*3600
hdulist[0].header['PUP_THRU'] = np.sum(tab[0].data)
hdulist[0].header['DET_SAMP'] = 1
hdulist[0].header['COMMENT'] = "From https://www.stsci.edu/hst/instrumentation/wfc3/data-analysis/psf"
hdulist[0].header['COMMENT'] = "with filter throughput removed and negative fluxes zeroed out"
hdulist[0].header['COMMENT'] = "Generated 2020.1014 by A. Riedel with WFC3convert.py"
hdulist.writeto('{}_{}_{:0.4f}.fits'.format(instrument, aperture, avgwave.to_value(u.um)))
