import sys
import numpy as np
from astropy.io import fits
from matplotlib import pyplot as plt

# file1 and file2 should both be JWST background fits files, as generated by the
# pandeia/devtools/canned_background.py, pandeia/devtools/canned_dated_background.py,
# or the webapp.
file1 = sys.argv[1]
file2 = sys.argv[2]

tab1 = fits.open(file1)
tab2 = fits.open(file2)

fig = plt.figure(figsize=(12,5))
ax1 = fig.add_subplot(2,4,1)
ax2 = fig.add_subplot(2,4,2)
ax3 = fig.add_subplot(2,4,3)
ax4 = fig.add_subplot(2,4,4)
ax5 = fig.add_subplot(2,4,5)
ax6 = fig.add_subplot(2,4,6)
ax7 = fig.add_subplot(2,4,7)
ax8 = fig.add_subplot(2,4,8)

names = [[ax1, ax5, 'background',"Background (total)"],
         [ax2, ax6, 'infield', "Infield"],
         [ax3, ax7, 'thermal', "Thermal"],
         [ax4, ax8, 'straylight', "Stray Light"]]

for axis1,axis2,keyword,title in names:
    axis1.plot(tab1[1].data['wavelength'],tab1[1].data[keyword])
    axis1.plot(tab2[1].data['wavelength'],tab2[1].data[keyword])
    axis2.plot(tab1[1].data['wavelength'],(tab1[1].data[keyword]-tab2[1].data[keyword])/tab1[1].data[keyword])
    axis1.set_title(title)
    axis1.set_ylabel("MJy/sr")
    axis2.set_ylabel("(old-new)/old")
    axis2.set_xlabel("microns")

plt.suptitle(file2.split("/")[-1].split(".")[0])
plt.tight_layout()
plt.show()
