#!/usr/bin/env python

from astropy.table import Table

from pandeia.engine.io_utils import write_json

"""
This script parses the summary.csv file and creates a structured JSON file where a galaxy's
information and spectrum can be looked up by galaxy name.  It is to be run in the same directory
as the Brown et al. data files and expects FITS filenames as generated by brown2fits.py.
"""
t = Table.read("summary.csv", format="ascii.csv")

cols = t.colnames

config = {}
for i in range(len(t)):
    key = t['Name'][i].replace(" ", "_").lower()
    filename = key + "_spec.fits"
    config[key] = {}
    config[key]['filename'] = filename
    config[key]['display'] = False
    config[key]['display_string'] = "%s (%s; %s)" % (t['Name'][i], t['Morphology'][i], t['BPT'][i])
    for c in cols[1:]:
        config[key][c] = t[c][i]

write_json(config, "spectra_all.json")
