import sys
import os
import glob
from pandeia.engine.coords import Grid

import time

import numpy as np
from scipy import optimize as op
from scipy import special as sp
from matplotlib import pyplot as plt

from astropy.io import fits


def airy(corradius, mirrorrad):
    #http://web.ipac.caltech.edu/staff/fmasci/home/astro_refs/PSFtheory.pdf
    u = mirrorrad*corradius
    flux = (2*sp.jn(1,u)/u)**2
    integ = (-4*np.pi) * (sp.jn(0,u)**2 + sp.jn(1,u)**2 - 1)
    integ = integ/integ[-1]
    flux[np.isnan(flux)] = 1

    return flux

def create_airy(wavelength, mirrorrad, pixelscale, pix_size):
    if pix_size%2 = 0:
        pix_size += 1
    # the array to hold the data
    image = np.zeros_like(2*image_size/pixelscale-1, 2*image_size/pixelscale-1)
    imcen = np.array([(image.shape[0] - 1) / 2., (image.shape[1] - 1) / 2.])
    y, x = np.indices(image.shape, dtype=float)
    radius = (np.sqrt((x-imcen[0])**2 + (y-imcen[1])**2) * pixelscale).flatten()
    thru = image.flatten()/np.max(image)

    corradius = np.pi/wavelength*radius

    flux = airy(corradius,mirrorrad)

def measure_fwhm(hdulist):
    image = hdulist[0].data
    pixelscale = hdulist[0].header['PIXELSCL']
    wavelength = hdulist[0].header['WAVELEN']*1e6
    imcen = np.array([(image.shape[0] - 1) / 2., (image.shape[1] - 1) / 2.])
    y, x = np.indices(image.shape, dtype=float)
    radius = (np.sqrt((x-imcen[0])**2 + (y-imcen[1])**2) * pixelscale).flatten()
    thru = image.flatten()/np.max(image)

    sorting = np.argsort(radius)
    radius = radius[sorting]
    thru = thru[sorting]
    corradius = np.pi/wavelength*radius

    plt.plot(radius,thru)

    popt, pcov = op.curve_fit(airy,corradius,thru/np.max(thru),p0=[5.6])

    radius = np.linspace(0,np.max(radius),10000)
    corradius = np.pi/wavelength*radius
    flux = airy(corradius, popt[0])

    plt.plot(radius,flux)

    hwhm = radius[np.nanargmin(np.abs(flux - 0.5))]

    plt.vlines(hwhm,0,1)
    plt.hlines(0.5,0,np.max(radius))
    plt.xscale('log')
    #plt.yscale('log')
    plt.savefig("{}.png".format(time.time()))
    plt.clf()
    #print(popt,hwhm*2, np.max(image))
    return hwhm*2

def measure_ee(hdulist):
    image = hdulist[0].data
    pixelscale = hdulist[0].header['PIXELSCL']
    wavelength = hdulist[0].header['WAVELEN']*1e6
    grid = Grid(pixelscalex,pixelscaley,image.shape[0],image.shape[1])
    imcen = np.array([(image.shape[0] - 1) / 2., (image.shape[1] - 1) / 2.])
    y, x = np.indices(image.shape, dtype=float)
    radius = (np.sqrt((x-imcen[0])**2 + (y-imcen[1])**2) * pixelscale)

    maximg = np.max((x-imcen[0]) * pixelscale)


    subr = []
    subs = []
    for r in np.linspace(0,maximg,100):
        mask = grid.circular_mask(r)
        subr.append(r)
        subs.append(np.sum(image*mask))
    # normalize to max of function
    subs = subs/subs[-1]
    ee = subr[np.nanargmin(np.abs(subs - 0.8))]

    plt.plot(subr,subs)
    plt.hlines(0.7,0, subr[-1])
    plt.hlines(0.8,0, subr[-1])
    plt.vlines(ee,0,1)
    plt.savefig("{}.png".format(time.time()))
    plt.clf()

    #print(ee)
    return ee

if __name__ == "__main__":
    instrument = sys.argv[1]
    data_dir = os.environ['pandeia_refdata']
    psf_folder = '{0:}/jwst/{1:}/psfs'.format(data_dir,instrument)

    psfs = glob.glob("{}/*.fits".format(psf_folder))

    outfile = open('{}/{}.csv'.format(psf_folder,instrument),'w')
    outfile.write('name,wavelength,xpos,ypos,fwhm,ee80,\n')

    for psf_file in psfs:
        hdulist = fits.open(psf_file)
        fwhm = measure_fwhm(hdulist)
        ee80 = measure_ee(hdulist)
        filename = psf_file.split('/')[-1].replace('.fits','')
        wavelength = filename.split('_')[2]
        if len(filename.split('_')) > 3:
            xpos = filename.split('_')[3]
            ypos = filename.split('_')[4]
        else:
            xpos = 0
            ypos = 0

        outfile.write('{},{},{},{},{},{},\n'.format(filename,wavelength,xpos,ypos,fwhm,ee70))

        hdulist.close()
    outfile.close()
