'''
Script to create scamp dispersion reference files for NIRISS from input .csv resolving powers.
A constant pixel sampling is assumed.

'''
import numpy as np
import scipy.interpolate as ip
from astropy.io import fits
import astropy.io.ascii as at

'''
Actual sampling is currently not available. Assume Nyquist for now for GR700XD. For the GR150 grisms,
we know that dlds is a constant 0.0048 micron/pixel.
'''
sampling = 2.
npix = 2048

files = [{'input': 'gr150c_r.csv', 'output': 'gr150c_disp.fits', 'sampling': 1.845},
         {'input': 'gr150r_r.csv', 'output': 'gr150r_disp.fits', 'sampling': 1.845},
         {'input': 'gr700xd_1_r.csv',
          'output': 'gr700xd_1_disp.fits',
          'sampling': 2.},
         {'input': 'gr700xd_2_r.csv', 'output': 'gr700xd_2_disp.fits', 'sampling': 2.}]

path = '../jwst/niriss/dispersion/'

for file in files:
    sampling = file['sampling']
    data = at.read(path + file['input'])
    wave = data['col1']
    dlds = ip.interp1d(wave, wave / data['col2'] / sampling)
    rpower = ip.interp1d(wave, data['col2'])
    lrange = (np.min(wave), np.max(wave))

    wave_pt = lrange[0]
    wave_pix = []
    while wave_pt < lrange[1]:
        wave_pix.append(wave_pt)
        wave_pt += dlds(wave_pt)

    wave_pix = np.array(wave_pix)
    npix = wave_pix.shape[0]
    pixels = np.arange(npix)

    c1 = fits.Column(name='PIXELS', unit='PIXELS', format='1D', disp='I4', array=pixels)
    c2 = fits.Column(name='WAVELENGTH', unit='UM', format='1D', disp='F10.1', array=wave_pix)
    c3 = fits.Column(name='DLDS', unit='UM', format='1D', disp='G12.5', array=dlds(wave_pix))
    c4 = fits.Column(name='R', unit='TRANSMISSION', format='1D', disp='G12.5', array=rpower(wave_pix))

    coldefs = fits.ColDefs([c1, c2, c3, c4])

    hdu = fits.PrimaryHDU()
    tbhdu = fits.BinTableHDU.from_columns(coldefs)
    thdulist = fits.HDUList([hdu, tbhdu])

    thdulist.writeto(path + file['output'], overwrite=True)
