from astropy.io import fits
import astropy.io.ascii as at
import pandas as pd
import numpy as np


def csv2fits_thruput(input, output, author, filename, comment):

    data = pd.read_csv(input)
    wave = data['WAVE']
    throughput = data['THROUGHPUT']

    c1 = fits.Column(name='WAVELENGTH', unit='MICRONS', format='E', disp='F10.1', array=wave)
    c2 = fits.Column(name='THROUGHPUT', unit='TRANSMISSION', format='E', disp='G12.5', array=throughput)

    coldefs = fits.ColDefs([c1, c2])

    hdu = fits.PrimaryHDU()
    tbhdu = fits.BinTableHDU.from_columns(coldefs)
    tbhdu.header['AUTHOR'] = author
    tbhdu.header['FILENAME'] = filename
    tbhdu.header['COMMENT'] = comment
    thdulist = fits.HDUList([hdu, tbhdu])

    thdulist.writeto(output, overwrite=True)

def csv2fits_dispersion(input, output, author, filename, comment):

    data = pd.read_csv(input)
    wave = data['WAVELENGTH']
    dlds = data['DLDS']
    r = data['R']

    c1 = fits.Column(name='WAVELENGTH', unit='MICRONS', format='E', disp='F10.1', array=wave)
    c2 = fits.Column(name='DLDS', unit='MICRONS/PIXEL', format='E', disp='G12.5', array=dlds)
    c3 = fits.Column(name='R', unit='RESOLUTION', format='E', disp='G12.5', array=r)

    coldefs = fits.ColDefs([c1, c2, c3])

    hdu = fits.PrimaryHDU()
    tbhdu = fits.BinTableHDU.from_columns(coldefs)
    tbhdu.header['AUTHOR'] = author
    tbhdu.header['FILENAME'] = filename
    tbhdu.header['COMMENT'] = comment
    thdulist = fits.HDUList([hdu, tbhdu])

    thdulist.writeto(output, overwrite=True)

def csv2fits_qe(input, output, author, filename, comment):

    data = pd.read_csv(input)
    wave = data['WAVE']
    throughput = data['THROUGHPUT']

    c1 = fits.Column(name='WAVELENGTH', unit='MICRONS', format='E', disp='F10.1', array=wave)
    c2 = fits.Column(name='THROUGHPUT', unit='TRANSMISSION', format='E', disp='G12.5', array=throughput)
    c3 = fits.Column(name='CONVERSION', unit='e-/photon', format='E', disp='G12.5', array=np.ones_like(wave))

    coldefs = fits.ColDefs([c1, c2, c3])

    hdu = fits.PrimaryHDU()
    tbhdu = fits.BinTableHDU.from_columns(coldefs)
    tbhdu.header['AUTHOR'] = author
    tbhdu.header['FILENAME'] = filename
    tbhdu.header['COMMENT'] = comment
    thdulist = fits.HDUList([hdu, tbhdu])

    thdulist.writeto(output, overwrite=True)
