import numpy as np
from scipy.optimize import curve_fit
from scipy.special import erf
from scipy.interpolate import interp1d

import glob
from astropy.io import fits
from matplotlib import pyplot as plt
import sys

def gauscdf(x,m,sigma):
    return 0.5*(1+erf((x-m)/(sigma*np.sqrt(2))))

def fit_cdf(dist,flux):

    
    flux = flux - np.min(flux)
    flux = flux/np.max(flux)
    sigma = 1
    popt,pcov = curve_fit(gauscdf,flux,dist,p0=[0.5,sigma])

    mean_param = popt[0]
    sig_param = popt[1]
    print(mean_param,sig_param)
    plt.plot(dist,flux)
    plt.show()


    return mean_param,sig_param

def loc(dist,flux, amt):
    flux = flux/np.max(flux)
    distloc = np.argmin(np.abs(flux-amt))

    return dist[distloc]
    

pattern = sys.argv[1]

files = glob.glob('{0:}*.fits'.format(pattern))

outfile = open('levels.csv','a')

psfsum = []
center = []
distances = []

#distances.append(-0.2)
#psfsum.append(0.0)
#center.append(0.0)

for x in range(len(files)):
    #print(files[x])
    data = fits.open(files[x])
    psfsum.append(np.sum(data[0].data))
    center.append(np.max(data[0].data))
    try:
        distances.append(float(files[x].split('_')[3]))
    except IndexError:
        distances.append(0)
    data.close()

#print(location)

# Yes, this interpolation is backwards, but that's because I want to query for distance
interpolator = interp1d((psfsum-np.min(psfsum))/(np.max(psfsum)-np.min(psfsum)),distances)

dist_25 = float(interpolator(1/4.))
dist_50 = float(interpolator(2/4.))
dist_75 = float(interpolator(3/4.))

dist_33 = float(interpolator(1/3.))
dist_66 = float(interpolator(2/3.))
dist_99 = float(interpolator(.99))

outfile.write('{0:},{1:},{2:},{3:},{4:},{5:},{6:}\n'.format(pattern,dist_25,dist_33,dist_50,dist_66,dist_75,dist_99))
outfile.close()

#mean,sigma = fit_cdf(distances,psfsum)

#dist = np.arange(0,np.max(distances),np.max(distances)/10000)
#flux = gauscdf(dist,mean,sigma)
#print(np.max(flux))
#dist_33 = loc(dist,flux,1/3.)
#dist_66 = loc(dist,flux,2/3.)
#dist_99 = loc(dist,flux,0.99)

fig = plt.figure(figsize=(14,12))
ax1 = fig.add_subplot(211)
ax2 = fig.add_subplot(212)
ax1.scatter(distances,psfsum, label='PSF Sum')
#ax1.plot(distances,(gauscdf(distances,mean,sigma)*(np.max(psfsum)-np.min(psfsum))+np.min(psfsum)))
ax1.vlines([dist_33,dist_66,dist_99],0,np.max(psfsum))
ax1.text(dist_33,np.max(psfsum)-0.15,'{0:5.4f}'.format(dist_33))
ax1.text(dist_66,np.max(psfsum)-0.1,'{0:5.4f}'.format(dist_66))
ax1.text(dist_99,np.max(psfsum)-0.05,'{0:5.4f}'.format(dist_99))
ax1.vlines([dist_25,dist_50,dist_75],0,np.max(psfsum))
ax1.text(dist_25,np.max(psfsum)-0.25,'{0:5.4f}'.format(dist_25))
ax1.text(dist_50,np.max(psfsum)-0.2,'{0:5.4f}'.format(dist_50))
ax1.text(dist_75,np.max(psfsum)-0.15,'{0:5.4f}'.format(dist_75))
ax2.plot(distances,center, label='PSF Peak')
ax1.set_title(pattern)
ax1.legend()
ax2.legend()
#ax1.set_yscale('log')
ax2.set_yscale('log')
ax1.grid()
ax2.grid()

plt.savefig('{0:}.png'.format(pattern.replace('*','')))
plt.close()

