import numpy as np
import glob
from astropy.io import fits
from matplotlib import pyplot as plt
import sys
from scipy.interpolate import interp1d

pattern = sys.argv[1]

files = glob.glob('{0:}*.fits'.format(pattern))
outfile = open('levels.csv','a')

wavelengths = []
for x in files:
    wavelengths.append(float(x.split('_')[2]))

wavelengths = np.sort(list(set(wavelengths)))

for wavelength in wavelengths:

    files = glob.glob('{0:}_{1:}*.fits'.format(pattern, wavelength))

    files = np.sort(files)
    xvals = []
    yvals = []

    for x in files:
        yvals.append(float(x.split('_')[4].replace('.fits','')))
        xvals.append(float(x.split('_')[3]))

    xvals = np.sort(list(set(xvals)))
    yvals = np.sort(list(set(yvals)))

    print(xvals,yvals)

    psfsum = np.zeros((len(xvals),len(yvals)))*np.nan
    center = np.zeros((len(xvals),len(yvals)))*np.nan

    for x in range(len(xvals)):
        for y in range(len(yvals)):
            try:
                data = fits.open('{0:}_{1:.4f}_{2:.3f}_{3:.3f}.fits'.format(pattern,wavelength,xvals[x],yvals[y]))
                psfsum[x][y] = np.sum(data[0].data)
                center[x][y] = np.max(data[0].data)
                data.close()
            except IOError:
                pass

    #psfsum = np.ma.masked_invalid(psfsum)
    #center = np.ma.masked_invalid(center)
    #print(location)
    print(len(yvals),len(psfsum[0]))


    fig = plt.figure(figsize=(14,12))
    ax1 = fig.add_subplot(211)
    ax2 = fig.add_subplot(212)
    for x in range(len(xvals)):
        centerdata = center[x]
        centerdata = centerdata[~np.isnan(centerdata)]
        #print(len(centerdata))
        #centerbar = np.arange(0,3,0.20)
        #print(len(centerbar))
        ax1.scatter(yvals,center[x]/np.max(center[x]), label=xvals[x])
        #ax1.scatter(centerbar,centerdata/np.max(centerdata), label=xvals[x])
        ax2.plot(yvals,psfsum[x], label=xvals[x])
        # Yes, this interpolation is backwards, but that's because I want to query for distance
        interpolator = interp1d((center[x]-np.min(center[x]))/(np.max(center[x])-np.min(center[x])),yvals)
        #interpolator = interp1d((centerdata-np.min(centerdata))/(np.max(centerdata)-np.min(centerdata)),centerbar)

        dist_25 = float(interpolator(1/4.))
        dist_50 = float(interpolator(2/4.))
        dist_75 = float(interpolator(3/4.))

        dist_33 = float(interpolator(1/3.))
        dist_66 = float(interpolator(2/3.))
        dist_99 = float(interpolator(.99))
        outfile.write('{0:},{1:},{2:},{3:},{4:},{5:},{6:},{7:},{8:}\n'.format(pattern,wavelength,xvals[x],dist_25,dist_33,dist_50,dist_66,dist_75,dist_99))
    #ax1.vlines([dist_33,dist_66,dist_99],0,np.max(center[5]))
    #ax1.text(dist_33,np.max(center[5])-0.15,'{0:5.4f}'.format(dist_33))
    #ax1.text(dist_66,np.max(center[5])-0.1,'{0:5.4f}'.format(dist_66))
    #ax1.text(dist_99,np.max(center[5])-0.05,'{0:5.4f}'.format(dist_99))
    #ax1.vlines([dist_25,dist_50,dist_75],0,np.max(center[5]))
    #ax1.text(dist_25,np.max(center[5])-0.25,'{0:5.4f}'.format(dist_25))
    #ax1.text(dist_50,np.max(center[5])-0.2,'{0:5.4f}'.format(dist_50))
    #ax1.text(dist_75,np.max(center[5])-0.15,'{0:5.4f}'.format(dist_75))
    ax1.set_title("{0:} {1:}".format(pattern, wavelength))
    ax1.legend(bbox_to_anchor=(0, 1), loc='upper left', ncol=1)
    ax2.legend(bbox_to_anchor=(0, 1), loc='upper left', ncol=1)
    ax1.set_xlabel('Arcsec')
    ax1.set_ylabel('Normalized')
    ax1.set_ylabel('Scaled')
    ax2.set_xlabel('Arcsec')
    #ax1.set_yscale('log')
    ax2.set_yscale('log')

    plt.savefig('{0:}_{1:}.png'.format(pattern.replace('*',''),wavelength))
    plt.close()

    #print(psfsum)

    sizes = np.ma.masked_invalid(np.log10(psfsum))
    sizediff = np.ma.max(sizes)-np.ma.min(sizes)
    sizescale = 100/sizediff
    sizemin = 0-np.ma.min(sizes)*sizescale
    print(sizescale,sizemin, np.ma.min(sizes),np.ma.max(sizes), np.ma.min(sizes)*sizescale+sizemin,np.ma.max(sizes)*sizescale+sizemin)



    pointsizes = np.log10(psfsum)*sizescale+sizemin

    print(len(xvals),len(yvals),pointsizes.shape)

    fig1 = plt.figure(figsize=(14,14))
    ax1 = fig1.add_subplot(111)
    for m in range(len(xvals)):
        for n in range(len(yvals)):
            ax1.scatter(xvals[m],yvals[n],s=pointsizes[m][n],c='k', edgecolor=None)

    ax1.set_xlim((np.min(xvals),np.max(xvals)))
    ax1.set_ylim((np.min(yvals),np.max(yvals)))
    ax1.set_title("{0:} {1:}".format(pattern, wavelength))

    fig1.savefig('{0:}_{1:}_radial.png'.format(pattern.replace('*',''),wavelength))
    plt.close()


outfile.close()
