import copy
import sys
import json
import operator

import numpy as np
from matplotlib import pyplot as plt

from pandeia.engine import calc_utils,perform_calculation

# Step 1: Read in the config file
# Step 2: Set up wavelength ranges
# Step 3: In a loop, modify the wavelength range
# Step 4: In the loop, run the engine and collect results

INSTRUMENT = "nircam"
APERTURE = "lw"
WIDTHS = np.arange(0.01,1,0.001)
#WIDTHS = [0.01, 0.012, 0.015, 0.02, 0.025, 0.03, 0.04, 0.05, 0.075, 0.08, 0.1, 0.12, 0.15, 0.2, 0.25, 0.3, 0.4, 0.5, 0.6, 0.7]

filtername = sys.argv[1]

# create a calc to run repeatedly
calc = calc_utils.build_default_calc('jwst','nircam','lw_imaging')
calc['configuration']['instrument']['filter'] = filtername

# open the configuration file and prepare to modify the wavelength range
with open('../jwst/{}/config.json'.format(INSTRUMENT)) as instfile:
    config = json.load(instfile)

config2 = copy.deepcopy(config)
range = config2['range'][APERTURE][filtername]

median = (range['wmin'] + range['wmax'])/2.
initial = range['wmax'] - range['wmin']

width_list = np.append(WIDTHS,initial)
width_list = sorted(width_list)[::-1]

data = []

for width in width_list:
    # set up config file
    with open('../jwst/{}/config.json'.format(INSTRUMENT), 'w') as instfile:
        config2['range'][APERTURE][filtername]['wmin'] = median - width/2.
        config2['range'][APERTURE][filtername]['wmax'] = median + width/2.
        json.dump(config2,instfile, indent=4, separators=(',', ': '))
        instfile.write('\n')

    results = perform_calculation.perform_calculation(calc)
    data.append({"width":width, "flux":results['scalar']['extracted_flux'],
            "sn":results['scalar']['sn'], "bg":results['scalar']['background_sky'],
            "wmin": median - width/2., "wmax": median + width/2.})
    print(data[-1])


# restore original config
with open('../jwst/{}/config.json'.format(INSTRUMENT), 'w') as instfile:
    json.dump(config,instfile)

width = [d['width'] for d in data]
max = [d['wmax'] for d in data]
flux = [d['flux'] for d in data]
sn = [d['sn'] for d in data]
bg = [d['bg'] for d in data]

fig = plt.figure()
ax1 = fig.add_subplot(221)
ax2 = fig.add_subplot(222)
ax3 = fig.add_subplot(223)
ax4 = fig.add_subplot(224)
ax1.plot(width,flux)
ax1.set_title("Flux")
ax1.set_xscale("log")
ax2.plot(max,sn)
ax2.set_title("SN")
ax3.plot(width,bg)
ax3.set_title("BG")
ax3.set_xscale("log")
#ax4.plot(widthget(data),fluxget(data))
ax1.vlines([initial],0,1.5)

plt.show()
