import os
from pandeia_test import data_util

def dispersercheck(self):
    for disperser in self.dispersers:
        filecheck(self, element=disperser, elements_all=self.disperser_all, elementname='Disperser', aperture=self.aperture)


def filtercheck(self):
    for filter in self.filters:
        filecheck(self, element=filter, elements_all=self.filter_all, elementname='Filter', aperture=self.aperture)


def filecheck(element=None, elements_all=None, elementname=None, aperture=self.aperture):
    if element not in elements_all:
        if element == None:
            pass
        print('   {0:} {1:} is not defined globally!'.format(elementname,element))
    if elementname == "Disperser":
        elementtype = '{0:}-{1:}'.format(self.aperture, element)
        elementpath = '{0:}_{1:}_disp'.format(self.aperture, element)
    else:
        elementtype = element
        elementpath = element
    if hasattr(self.config['paths'], elementpath):
        elementfile = self.config['paths'][elementpath]
        filename = "{0:}/{1:}/{2:}/{3:}".format(self.data_dir, self.telescope, self.instrument, elementfile)
        if os.path.isfile(filename):
            fitshdu = fits.open(filename)
            if fitshdu[0].header['COMPNAME'].strip().lower() != elementtype.lower():
                print('   {0:} {1:} says it is {2:}! ({3:})'.format(elementname, elementtype.lower(),
                                                                   fitshdu[0].header['COMPNAME'].strip().lower(),filename))
            else:
                print('   {0:} {1:} does not exist!'.format(elementname, filename))
    else:
        print("   {0:} {1:} has no definition file!".format(elementname,elementpath))


def psfcheck(self, minwave, maxwave, aperturemask=aperturemask):
    psflist = os.listdir("{0:}/{1:}/{2:}/psfs/".format(self.data_dir,self.telescope,self.instrument))
    psfcut = [x for x in psflist if aperturemask in x.split('_')[1].split('-')]
    maxpsf = 0
    minpsf = 99999
    for psf in psfcut:
        psfwave = float(psf.split('_')[2].replace('.fits',''))
        if psfwave > maxpsf:
            maxpsf = psfwave
        if psfwave < minpsf:
            minpsf = psfwave

        # Step 4b: Do they sum to 1?
        fitshdu = fits.open("{0:}/{1:}/{2:}/psfs/{3:}".format(self.data_dir,self.telescope,self.instrument,psf))
        outfile.write("{0:}: {1:7.5f} {2:7.5f} {3:7.5f} {4:} {5:}\n".format(psf,np.sum(fitshdu[0].data),np.max(fitshdu[0].data),np.sum(fitshdu[0].data[0:int(len(fitshdu[0].data)/3.0)][0:int(len(fitshdu[0].data)/3.0)]),fitshdu[0].header['PUPILOPD'],fitshdu[0].header['PUP_THRU']))

        # Step 4c: Are they what they appear to be?
        passed = True
        # it's only necessary that the aperture be IN that header keyword (see: nirspec, where the aperture keyword is a long list)
        if aperturemask.lower() not in fitshdu[0].header['aperture'].strip().lower():
            print('   PSF {0:} has aperture {1:}, not {2:}'.format(psf, fitshdu[0].header['aperture'].strip().lower(),aperturemask.lower()))
            passed = False
        psfwave_fits = "{0:.4f}".format(float(fitshdu[0].header['wavelen'])*1000000)
        if float(psfwave_fits) != float(psfwave):
            print('   PSF {0:} is for wavelength {1:}, not {2:}'.format(psf, psfwave_fits, psfwave))
            passed = False
        if hasattr(fitshdu[0].header, 'coronmsk'):
            if fitshdu[0].header['coronmsk'].strip().lower().replace(' ','') != self.aperture.lower():
                passed = False
                print('   PSF {0:} has wrong coronmsk ({1:})'.format(psf, fitshdu[0].header['coronmsk'].strip()))


    print("Expected wavelength coverage: {0:}--{1:}; actual: {2:}--{3:}".format(minwave,maxwave,minpsf,maxpsf))


def sanitycheck(self):
    for inst in ['miri','nircam','niriss','nirspec']:
        instrument = InstrumentConfiguration(inst,'jwst')
        instrument.get_modes()
        for mode in instrument.modes:
            instrument.set_mode(mode)
            instrument.get_apertures()
            for aperture in instrument.apertures:
                instrument.set_aperture(aperture)
                instrument.get_filters()
                instrument.get_dispersers()
                instrument.filtercheck()
                instrument.dispersercheck()
                waveelements = self.filters + self.dispersers
                if aperture in ['maskswb','masklwb']:
                    for element in waveelements:
                        minwave,maxwave = instrument.waverange(waveelements=element)
                        instrument.psfcheck(minwave,maxwave, aperturemask='{0:}{1:}'.format(aperture,element))
                else:
                    minwave,maxwave = instrument.waverange(waveelements=waveelements)
                    instrument.psfcheck(minwave,maxwave, aperturemask=aperture)
