import sys

import numpy as np
from scipy import interpolate
from astropy.io import fits
import matplotlib.pyplot as plt

infilename = sys.argv[1]
datadir = '/'.join(infilename.split('/')[:-1])

resel_per_pixel = {'stis': 2, 'wfc3,ir': 2, 'wfc3,uvis1':3, 'wfc3,uvis2': 3, 'cos,fuv': 6, 'cos,fuv,g130m,1055': 8, 'cos,fuv,g130m,1096': 9, 'cos,nuv':3, 'acs': 2, 'nirspec': 2}

with open(infilename) as infile:
    for line in infile:
        if line[0] != "#":
            obsmode,ranges = line.split()
            for r in resel_per_pixel:
                if r in obsmode:
                    resel = resel_per_pixel[r]
            print(obsmode,resel)
            if "synphot" not in ranges:
                ranges = ranges.replace('(','').replace(')','')
                waveranges = ranges.split(',')
                start = float(waveranges[0])
                stop = float(waveranges[1])
                if len(waveranges) == 4:
                    # in this case, we have an ever-increasing step size
                    step0 = float(waveranges[2])
                    step1 = float(waveranges[3])
                    stepfun = interpolate.interp1d([start,stop], [step0, step1], fill_value='extrapolate')
                    wavelengths = [start]
                    dlds = [waveranges[2]]
                    newwave = start
                    while newwave < stop:
                        newwave = wavelengths[-1] + stepfun(wavelengths[-1])
                        wavelengths.append(newwave)
                        dlds.append(stepfun(wavelengths[-1]))
                    wavelengths = np.array(wavelengths, dtype=float)
                    dlds = np.array(dlds, dtype=float)
                    print(dlds)
                elif len(waveranges) == 3:
                    step = float(waveranges[2])
                    print(step)
                    wavelengths = np.arange(start,stop,step)
                    dlds = np.ones_like(wavelengths) * step
            else:
                specfilename = ranges.split("$")[1].split('/')[1]
                with open(f"{datadir}/{specfilename}", "r") as specfile:
                    lines = specfile.read()
                    array = lines.split('\n')
                    wavelengths = []
                    for x in lines.split('\n'):
                        try:
                            wavelengths.append(float(x))
                        except ValueError:
                            pass
                    wavelengths = np.array(wavelengths)
                    dlds = wavelengths[1:] - wavelengths[:-1]
                    dlds = np.append(dlds, dlds[-1])
                    
            #dlds *= resel
            r = wavelengths/dlds
            wavecol = fits.Column(name="WAVELENGTH", array=wavelengths * 1e-4, format='E', unit='MICRONS')
            dldscol = fits.Column(name="DLDS", array=dlds * 1e-4, format='E', unit='MICRON/PIXEL')
            rcol = fits.Column(name="R", array=r, format='E', unit='RESOLUTION')
            
            hdr = fits.Header()
            hdr['TELESCOP'] = 'HST'
            hdr['INSTRUME'] = 'STIS'
            hdr['REFTYPE'] = 'DISPERSION'
            hdr['FILETYPE'] = 'DATA_TABLE'

            cols = fits.ColDefs([wavecol,dldscol,rcol])
            tab = fits.BinTableHDU.from_columns(cols)
            pri = fits.PrimaryHDU(header=hdr)
            hdu = fits.HDUList([pri, tab])

            outfilename = "hst_{}_disp.fits".format(obsmode.replace(',','_'))

            print(hdu[1].data)

            hdu.writeto(outfilename)

