import sys

import numpy as np
from astropy.io import ascii
from matplotlib import pyplot as plt

filename = sys.argv[1]

tab = ascii.read(filename)
print(tab, tab.keys())

JWST= np.where(tab['JWST'] == 'D')
yes = np.where(tab['JWST'] == 'Y')
no = np.where(tab['JWST'] == 'N')
down = np.where(tab['JWST'] == 'R')

fig = plt.figure(figsize=(12,8))
ax1 = fig.add_subplot(221)
ax2 = fig.add_subplot(222)
ax3 = fig.add_subplot(223)
ax4 = fig.add_subplot(224)
ax1.scatter(tab['time'][no],tab['mem'][no], facecolor=(0.9,0,0,0.3), edgecolor=(0,0,0,0), label="HST-only")
ax1.scatter(tab['time'][yes],tab['mem'][yes], facecolor=(0.1,0.1,1,0.3), edgecolor=(0,0,0,0), label="JWST")
ax1.scatter(tab['time'][JWST],tab['mem'][JWST], facecolor=(0,0.7,0,0.3), edgecolor=(0,0,0,0), s=50, label="Current JWST")
ax1.scatter(tab['time'][down],tab['mem'][down], facecolor=(1,0.7,0,0.9), edgecolor=(0,0,0,0), s=60, label="Downsampled for JWST")
ax1.set_xlabel('Time (s)')
ax1.set_ylabel('Mem (bytes)')
ax1.legend(scatterpoints=1)

ax2.scatter(tab['time'][no],tab['r_med'][no], facecolor=(0.9,0,0,0.3), edgecolor=(0,0,0,0))
ax2.scatter(tab['time'][yes],tab['r_med'][yes], facecolor=(0.1,0.1,1,0.3), edgecolor=(0,0,0,0))
ax2.scatter(tab['time'][JWST],tab['r_med'][JWST], facecolor=(0,0.7,0,0.3), edgecolor=(0,0,0,0), s=50)
ax2.scatter(tab['time'][down],tab['r_med'][down], facecolor=(1.0,0.7,0,0.9), edgecolor=(0,0,0,0), s=60, label="Downsampled for JWST")
ax2.set_xlabel('Time (s)')
ax2.set_ylabel('Median Resolving Power')
ax2.set_yscale('log')

ax3.scatter(tab['time'][no],tab['filesize'][no], facecolor=(0.9,0,0,0.3), edgecolor=(0,0,0,0))
ax3.scatter(tab['time'][yes],tab['filesize'][yes], facecolor=(0.1,0.1,1,0.3), edgecolor=(0,0,0,0))
ax3.scatter(tab['time'][JWST],tab['filesize'][JWST], facecolor=(0,0.7,0,0.3), edgecolor=(0,0,0,0), s=50)
ax3.scatter(tab['time'][down],tab['filesize'][down], facecolor=(1.0,0.7,0,0.9), edgecolor=(0,0,0,0), s=60, label="Downsampled for JWST")
ax3.set_xlabel('Time (s)')
ax3.set_ylabel('File Size (bytes)')
ax3.set_yscale('log')

ax4.scatter(tab['mem'][no],tab['filesize'][no], facecolor=(0.9,0,0,0.3), edgecolor=(0,0,0,0))
ax4.scatter(tab['mem'][yes],tab['filesize'][yes], facecolor=(0.1,0.1,1,0.3), edgecolor=(0,0,0,0))
ax4.scatter(tab['mem'][JWST],tab['filesize'][JWST], facecolor=(0,0.7,0,0.3), edgecolor=(0,0,0,0), s=50)
ax4.scatter(tab['mem'][down],tab['filesize'][down], facecolor=(1.0,0.7,0,0.9), edgecolor=(0,0,0,0), s=60, label="Downsampled for JWST")
ax4.set_xlabel('Memory Usage (bytes)')
ax4.set_ylabel('File Size (bytes)')
ax4.set_yscale('log')

plt.tight_layout()

plt.savefig('Spectra_analysis.png', dpi=200)
