"""
This script updates the specified header keyword of a batch of FITS files with
a specified new value.

Calling sequence is
python value_updater.py PATH KEYWORD VALUE
For example,
python value_updater.py ../jwst/miri/psfs/miri_fqpm1065_ PUP_THRU 0.5884549526597925

The output is self-verification that the script worked and actually changed the
files, and will not add keywords to FITS files that do not have them.
"""

import sys
import glob
from astropy.io import fits

path = sys.argv[1]
keyword = sys.argv[2]
#value = sys.argv[3]

files = glob.glob('{0:}*.fits'.format(path))
files = sorted(files)

for filename in files:
    hdulist = fits.open(filename)
    if keyword in hdulist[0].header:
        print("File {}: Keyword {}: {}".format(filename,keyword, hdulist[0].header[keyword]))
    else:
        print("File {}: Keyword {} not present".format(filename,keyword))
    hdulist.close()
