"""
This script updates the specified header keyword of a batch of FITS files with
a specified new value.

Calling sequence is
python value_updater.py PATH KEYWORD VALUE (ADD)
For example,
python value_updater.py ../jwst/miri/psfs/miri_fqpm1065_ PUP_THRU 0.5884549526597925

The output is self-verification that the script worked and actually changed the
files, and will not add keywords to FITS files that do not have them.
"""

import sys
import glob
from astropy.io import fits
import numpy as np

operation = sys.argv[1]
path = sys.argv[2]


files = glob.glob('{0:}*'.format(path))



if operation in ("ADD", "UPDATE"):
    value = sys.argv[4]
    try:
        value = float(value)
    except (ValueError, TypeError):
        pass
    try:
        if value % 1 == 0.0:
            value = int(value)
    except (ValueError, TypeError):
        pass
if operation in ("RENORM", "CUSTOM"):
    value = sys.argv[3]
    try:
        value = float(value)
    except (ValueError):
        pass
    try:
        if value % 1 == 0.0:
            value = int(value)
    except (ValueError, TypeError):
        pass

if operation not in ("VIEWALL", "VIEW_ALL", "RENORM", "CUSTOM"):
    keyword = sys.argv[3]

for filename in files:
    hdulist = fits.open(filename, mode="update")
    if operation == "ADD":
        hdulist[0].header[keyword] = value
        print("File {}: Keyword {} is {}".format(filename, keyword, hdulist[0].header[keyword]))
    if operation == "UPDATE":
        if (keyword in hdulist[0].header):
            hdulist[0].header[keyword] = value
            print("File {}: Keyword {} is {}".format(filename, keyword, hdulist[0].header[keyword]))
        else:
            print("File {}: Keyword {} not present and not updated".format(filename,keyword))
    if operation == "DELETE":
        if (keyword in hdulist[0].header):
            del hdulist[0].header[keyword]
        else:
            print("File {}: Keyword {} not present and not deleted".format(filename,keyword))
    if operation == "VIEW":
        if (keyword in hdulist[0].header):
            print("File {}: Keyword {} is {}".format(filename, keyword, hdulist[0].header[keyword]))
        else:
            print("File {}: Keyword {} not present".format(filename,keyword))
    if operation == "RENORM":
        was = np.max(hdulist[0].data)
        hdulist[0].data *= value
        hdulist[0].header['PUP_THRU'] = np.sum(hdulist[0].data)
        print("File {}: MAX was {}, is now {}".format(filename, was, np.max(hdulist[0].data)))
    if operation in ("VIEWALL", "VIEW_ALL"):
        print("-----------------------------\n {}\n-----------------------------".format(filename))
        print(hdulist[0].header)
    if operation == "CUSTOM":
        exec(value)
        print("-----------------------------\n {}\n-----------------------------".format(filename))
        print(hdulist[0].header)
    #hdulist.flush()
    hdulist.close()

    # Verify updated data
    # hdu = fits.open(filename)
    # if keyword in hdu[0].header:
    #     print("File {}: Keyword {} is {}".format(filename, keyword, hdu[0].header[keyword]))
    # else:
    #     print("File {}: Keyword {} not present".format(filename,keyword))
    # hdu.close()
