import sys
from astropy.io import fits, ascii
import numpy as np
import pysynphot as psyn

from pandeia.engine import config as cf

pandeia_refdata = cf.default_refdata_directory

filename = sys.argv[1]
bgname = '{}/wfirst/background/{}'.format(pandeia_refdata,filename)

tab = fits.open('{}/jwst/background/{}'.format(pandeia_refdata,filename))

wfirst = ascii.read("{}/wfirst/telescope/thermal_curve_roman_rryan_v1.0.csv".format(pandeia_refdata))

headerdata = tab[1].header

bg_tel_wave = wfirst['col1']
bg_tel_flux = wfirst['col2']

headerdata['comment'] = "This is placeholder data for a future Roman-specific background model."
headerdata['comment'] = "It uses a Roman thermal profile (for Detector 1) from August 2020,"
headerdata['comment'] = "combined with an infield background generated from the JWST background"
headerdata['comment'] = "tool to roughly estimate the Roman background."

print(headerdata)
#print(wfirst[1].header)

influx = tab[1].data.field('infield')
inwave = tab[1].data.field('wavelength')

infield = psyn.ArraySpectrum(wave=inwave, flux=influx, waveunits='microns')

tel_spec = psyn.ArraySpectrum(wave=bg_tel_wave, flux=bg_tel_flux, waveunits='microns')

bg = tel_spec + infield

#for x in range(len(bg.wave)):
#    print(bg.wave[x], bg.flux[x], bg_tel_wave[x], bg_tel_flux[x], infield.sample(bg.wave[x]))

c1 = fits.Column(name='wavelength', array=bg.wave, format='E')
c2 = fits.Column(name='background', array=bg.flux, format='E')
c3 = fits.Column(name='thermal', array=tel_spec.sample(bg.wave), format='E')
c4 = fits.Column(name='infield', array=infield.sample(bg.wave), format='E')

t = fits.BinTableHDU.from_columns([c1, c2, c3, c4], header=headerdata)
t.writeto(bgname)
tab.close()
